// Display an Overlay and Highlight an Active Element
import React, { useEffect } from "react";
import "./Overlay.css";
import { IOverlayProps } from "./Interface.type";

const Overlay: React.FC<IOverlayProps> = ({
  activeElementId,
  onClose,
  colorConfig,
}) => {
  useEffect(() => {
    if (activeElementId) {
      const activeElement = document.getElementById(activeElementId); // Find the element with the specified ID

      if (activeElement) {     // Highlight the active element with styles
        activeElement.style.position = "absolute";
        activeElement.style.zIndex = "1000";
        activeElement.style.boxShadow = `0 0 10px ${
          colorConfig.highlightColor || "green"
        }`;
      }

      return () => {             // Cleanup: Reset styles on component unmount or when activeElementId changes
        if (activeElement) {
          activeElement.style.position = "";
          activeElement.style.zIndex = "";
          activeElement.style.boxShadow = "";
        }
      };
    }
  }, [activeElementId, colorConfig.highlightColor]);

  return (
    <div
      className="fixed top-0 left-0 w-full h-full"              // Utility classes for overlay positioning
      style={{
        backgroundColor:
          colorConfig.overlayBackgroundColor || "rgba(0, 0, 0, 0.5)",     // // Fallback background color
        zIndex: 999,
      }}
      onClick={onClose}
    />
  );
};

export default Overlay;
