import { useState, useEffect } from "react";

// Custom hook to track the width of the viewport
export const useViewport = () => {
    // State to store the current width of the viewport
  const [width, setWidth] = useState(window.innerWidth);

    // Effect to handle window resize and update the width
  useEffect(() => {
        // Function to update the width state when the window is resized
    const handleResize = () => setWidth(window.innerWidth);
    window.addEventListener("resize", handleResize);        // Add event listener to detect window resize

    return () => window.removeEventListener("resize", handleResize);     // Cleanup function to remove the event listener when the component unmounts
  }, []);

  return width;    // Return the current width of the viewport
};
